@@ -3,6 +3,9 @@ module.exports = {
     "es6": true,
     "node": true
   },
+  "plugins": [
+    "mocha"
+  ],
   "extends": "eslint:recommended",
   "rules": {
     "indent": [
@@ -20,6 +23,7 @@ module.exports = {
     "semi": [
       "error",
       "always"
-    ]
+    ],
+    "no-extra-boolean-cast": 0
   }
 };
